==> kubernetes-model-extensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/extensions/NetworkPolicyIngressRuleBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NetworkPolicyIngressRuleBuilder extends io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleFluentImpl<io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRule,io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleBuilder>{
  public NetworkPolicyIngressRuleBuilder() {
    this(false);
  }
  public NetworkPolicyIngressRuleBuilder(java.lang.Boolean validationEnabled) {
    this(new NetworkPolicyIngressRule(), validationEnabled);
  }
  public NetworkPolicyIngressRuleBuilder(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public NetworkPolicyIngressRuleBuilder(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NetworkPolicyIngressRule(), validationEnabled);
  }
  public NetworkPolicyIngressRuleBuilder(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRule instance) {
    this(fluent, instance, false);
  }
  public NetworkPolicyIngressRuleBuilder(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFrom(instance.getFrom()); 
    fluent.withPorts(instance.getPorts()); 
    this.validationEnabled = validationEnabled; 
  }
  public NetworkPolicyIngressRuleBuilder(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRule instance) {
    this(instance,false);
  }
  public NetworkPolicyIngressRuleBuilder(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFrom(instance.getFrom()); 
    this.withPorts(instance.getPorts()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRule build() {
    NetworkPolicyIngressRule buildable = new NetworkPolicyIngressRule(fluent.getFrom(),fluent.getPorts());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkPolicyIngressRuleBuilder that = (NetworkPolicyIngressRuleBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-extensions-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/extensions/NetworkPolicyIngressRuleBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NetworkPolicyIngressRuleBuilder extends io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleFluentImpl<io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRule,io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleBuilder>{
  public NetworkPolicyIngressRuleBuilder() {
    this(false);
  }
  public NetworkPolicyIngressRuleBuilder(java.lang.Boolean validationEnabled) {
    this(new NetworkPolicyIngressRule(), validationEnabled);
  }
  public NetworkPolicyIngressRuleBuilder(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public NetworkPolicyIngressRuleBuilder(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NetworkPolicyIngressRule(), validationEnabled);
  }
  public NetworkPolicyIngressRuleBuilder(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRule instance) {
    this(fluent, instance, false);
  }
  public NetworkPolicyIngressRuleBuilder(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFrom(instance.getFrom()); 
    fluent.withPorts(instance.getPorts()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NetworkPolicyIngressRuleBuilder(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRule instance) {
    this(instance,false);
  }
  public NetworkPolicyIngressRuleBuilder(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFrom(instance.getFrom()); 
    this.withPorts(instance.getPorts()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRuleFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyIngressRule build() {
    NetworkPolicyIngressRule buildable = new NetworkPolicyIngressRule(fluent.getFrom(),fluent.getPorts());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkPolicyIngressRuleBuilder that = (NetworkPolicyIngressRuleBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
